@@ -11,17 +11,13 @@
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
-import enum
-
-EVENT_TYPE_KEY = "eventType"
 EVENT_PREDICTION_ID = "predictionId"
 EVENT_TIMESTAMP = "timestamp"
 EVENT_FEATURES = "features"
 EVENT_PREDICTION = "prediction"
+LABELS = "labels"
 EVENT_PREDICTION_VALUE = "value"
 EVENT_PREDICTION_PROBABILITY = "probability"
 EVENT_WORKSPACE_NAME = "workspaceName"
-
-
-class EventTypes(enum.Enum):
-    Prediction = "prediction"
+EVENT_MODEL_NAME = "modelName"
+EVENT_MODEL_VERSION = "modelVersion"
